@@ -1,6 +1,5 @@
 import configparser
 import os
-from requests import Session
 
 from . import models
 from .auth import ApiTokenAuth
@@ -10,7 +9,6 @@ from .models.utils import CachedProperty
 from .requestor import Requestor, urljoin
 from .serializer import Serializer
 
-
 User = models.User
 Bot = models.Bot
 RedditApp = models.RedditApp
@@ -349,8 +347,7 @@ class CredentialManager(object):
         :param Union[int,str,User] owner: Return UserVerifications that are owned by
             this user
 
-        :returns: A :class:`.Paginator` to iterate through the
-            UserVerifications
+        :returns: A :class:`.Paginator` to iterate through the UserVerifications.
 
         """
         return UserVerification(self).listItems(
@@ -382,8 +379,7 @@ class CredentialManager(object):
         :param Union[int,str,User] owner: Return DatabaseCredentials that are owned by
             this user
 
-        :returns: A :class:`.Paginator` to iterate through the
-            DatabaseCredentials
+        :returns: A :class:`.Paginator` to iterate through the DatabaseCredentials
 
         """
         return DatabaseCredential(self).listItems(
